import "package:flutter/material.dart";
import 'package:flutter/cupertino.dart';
import "dart:io" show Platform;
import "package:flutter/foundation.dart" show kIsWeb;

void main() => runApp(AppRoot());

class AppRoot extends StatelessWidget {
  Widget build(BuildContext context) {
    if (kIsWeb) {
      print('Deze app draait op het web');
    } else {
      print('Deze app draait op ' + Platform.operatingSystem);
    }

    return MaterialApp(
      home: Scaffold(appBar: AppBar(title: Text("Mijn App")), body: AppTree()),
      debugShowCheckedModeBanner: false,
      theme: ThemeData.light(),
    );
  }
}

class AppTree extends StatefulWidget {
  @override
  _AppTreeState createState() => _AppTreeState();
}

class _AppTreeState extends State<AppTree> {
  bool zichtbaar = true;
  double grootte = 100;
  int dropDownWaarde = 100;

  List<DropdownMenuItem<int>> lijstOpties = [
    DropdownMenuItem(child: Text('Groot'), value: 200),
    DropdownMenuItem(child: Text('Normaal'), value: 100),
    DropdownMenuItem(child: Text('Klein'), value: 30),
  ];

  Widget build(BuildContext context) {
    return Column(
      children: [
        Row(
          children: [
            Radio(
              value: false,
              groupValue: zichtbaar,
              onChanged: (waarde) {
                print(waarde);
                setState(() {
                  zichtbaar = false;
                });
              },
            ),
            Radio(
              value: true,
              groupValue: zichtbaar,
              onChanged: (waarde) {
                print(waarde);
                setState(() {
                  zichtbaar = true;
                });
              },
            ),
            Checkbox(
              value: zichtbaar,
              onChanged: (waarde) {
                print(waarde);
                setState(() {
                  zichtbaar = !zichtbaar;
                });
              },
            ),
            Switch.adaptive(
              value: zichtbaar,
              onChanged: (waarde) {
                print(waarde);
                setState(() {
                  zichtbaar = !zichtbaar;
                });
              },
            ),
            DropdownButton<int>(
              items: lijstOpties,
              value: dropDownWaarde,
              onChanged: (waarde) {
                setState(() {
                  grootte = waarde!.toDouble();
                  dropDownWaarde = waarde;
                });
              },
            ),
          ],
        ),
        Slider.adaptive(
          min: 20,
          max: 300,
          value: grootte,
          onChanged: (double value) {
            setState(() {
              grootte = value;
            });
          },
        ),
        TextField(
          decoration: InputDecoration(
              filled: true,
              fillColor: Colors.grey[200],
              border: InputBorder.none,
              hintText: 'Voer hier uw tekst in'),
          onChanged: (tekstInvoer) {
            print("Ingevoerde tekst: $tekstInvoer");
          },
        ),
        Center(
            child: Visibility(
          visible: zichtbaar,
          child: FlutterLogo(size: grootte),
        )),
      ],
    );
  }
}
