import "package:flutter/material.dart";

void main() => runApp(AppRoot());

class AppRoot extends StatelessWidget {
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(appBar: AppBar(title: Text("Mijn App")), body: AppTree()),
      debugShowCheckedModeBanner: false,
      theme: ThemeData.light(),
    );
  }
}

class AppTree extends StatefulWidget {
  @override
  _AppTreeState createState() => _AppTreeState();
}

class _AppTreeState extends State<AppTree> with SingleTickerProviderStateMixin {
  late Animation<double> animatie;
  late AnimationController animatieController;
  void initState() {
    animatieController =
        AnimationController(duration: const Duration(seconds: 5), vsync: this);
    animatie = Tween<double>(begin: 0, end: 6.28).animate(animatieController);
    animatie.addListener(() {
      setState(() {});
    });
    animatieController.forward();
    animatie.addStatusListener((status) {
      if (status == AnimationStatus.completed) {
        animatieController.repeat();
      }
    });
    super.initState();
  }

  void dispose() {
    animatieController.dispose();
    super.dispose();
  }

  Widget build(BuildContext context) {
    return CustomPaint(
        painter: PainterTest(animatie.value),
        size: MediaQuery.of(context).size);
  }
}

class PainterTest extends CustomPainter {
  final double startHoek;
  PainterTest(this.startHoek);

  void paint(Canvas canvas, Size size) {
    const aantalCirkels = 50;
    final paint = Paint()
      ..color = Colors.blue
      ..style = PaintingStyle.stroke
      ..strokeWidth = 2.0;
    for (int i = 1; i < aantalCirkels; i++) {
      Rect rechthoek = Rect.fromLTWH(
          size.width / aantalCirkels * i,
          size.height / aantalCirkels * i,
          size.width - size.width / aantalCirkels * i * 2,
          size.height - size.height / aantalCirkels * i * 2);
      canvas.drawArc(rechthoek, startHoek, 1.7, true, paint);
    }
  }

  bool shouldRepaint(CustomPainter oldDelegate) {
    return true;
  }
}
