import "package:flutter/material.dart";
import 'package:shared_preferences/shared_preferences.dart';

void main() => runApp(AppRoot());

class AppRoot extends StatelessWidget {
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(appBar: AppBar(title: Text("Mijn App")), body: AppTree()),
      debugShowCheckedModeBanner: false,
      theme: ThemeData.light(),
    );
  }
}

class AppTree extends StatefulWidget {
  @override
  _AppTreeState createState() => _AppTreeState();
}

class _AppTreeState extends State<AppTree> {
  int getal = 0;
  Widget build(BuildContext context) {
    return FutureBuilder<dynamic>(
        future: read("laatsteGetal"),
        builder: (context, snapshot) {
          getal = snapshot.data ?? 0;
          if (snapshot.connectionState == ConnectionState.waiting) {
            return Container();
          }
          return Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                Text(getal.toString(), textScaleFactor: 2),
                FloatingActionButton(
                    child: Icon(Icons.plus_one),
                    onPressed: () async {
                      setState(() {
                        getal++;
                        save("laatsteGetal", getal);
                      });

                      // futures gebruiken:
                      dynamic test = read('laatsteGetal')
                          .toString(); //geeft Future terug, niet de waarde
                      print('read("laatsteGetal") -> $test');

                      read('laatsteGetal').then((waarde) {
                        print('read("laatsteGetal") ->  $waarde');
                      });

                      test = await read('laatsteGetal'); //werkt alleen in async
                      print('await read("laatsteGetal") ->  $test');
                    })
              ],
            ),
          );
        });
  }

  Future<void> save(String naam, int waarde) async {
    final prefs = await SharedPreferences.getInstance();
    prefs.setInt(naam, waarde);
    //print("$waarde opgeslagen in $naam");
  }

  Future<int> read(String naam) async {
    final prefs = await SharedPreferences.getInstance();
    final waarde = prefs.getInt(naam) ?? 0;
    //print("$waarde werd uitgelezen");
    return waarde;
  }
}
