import 'package:flutter/material.dart';
import '../bibliotheek.dart' as lib;
import 'package:audioplayers/audioplayers.dart';

class AntwoordKnop extends StatefulWidget {
  final bool isJuist;
  final String antwoord;
  final Function verwerkAntwoord;

  AntwoordKnop(this.antwoord, this.isJuist, this.verwerkAntwoord);
  _AntwoordKnopState createState() => _AntwoordKnopState();
}

class _AntwoordKnopState extends State<AntwoordKnop>
    with SingleTickerProviderStateMixin {
  final AudioPlayer audioSpeler = AudioPlayer();
  late AnimationController animatieController;
  late Animation<Color?> kleurAnimatie, randAnimatie;
  late Animation<double> vervaagAnimatie;

  initState() {
    animatieController =
        AnimationController(vsync: this, duration: Duration(milliseconds: 500));
    kleurAnimatie =
        ColorTween(begin: Colors.blue[100]).animate(animatieController);
    randAnimatie = ColorTween(begin: Colors.blue).animate(animatieController);
    vervaagAnimatie =
        Tween<double>(begin: 1, end: 0.3).animate(animatieController);
    kleurAnimatie.addListener(() {
      setState(() {});
    });
    kleurAnimatie.addStatusListener((status) {
      if (status == AnimationStatus.completed) {
        widget.verwerkAntwoord(widget.isJuist);
        animatieController.reset();
      }
    });
    super.initState();
  }

  void dispose() {
    animatieController.dispose();
    super.dispose();
  }

  Widget build(BuildContext context) {
    double knopBreedte =
        MediaQuery.of(context).size.width * 0.5 - lib.tekstMarge * 2;

    return Padding(
      padding: const EdgeInsets.all(lib.tekstMarge),
      child: GestureDetector(
        onTap: () {
          Color eindKleur;
          String geluid;
          if (widget.isJuist) {
            eindKleur = Colors.green;
            geluid = 'audio/goed.mp3';
          } else {
            eindKleur = Colors.red;
            geluid = 'audio/fout.mp3';
          }
          audioSpeler.play(AssetSource(geluid));
          kleurAnimatie = ColorTween(begin: Colors.blue[100], end: eindKleur)
              .animate(animatieController);
          randAnimatie = ColorTween(begin: Colors.blue, end: eindKleur)
              .animate(animatieController);
          animatieController.forward();
        },
        child: Opacity(
          opacity: vervaagAnimatie.value,
          child: ConstrainedBox(
            constraints: BoxConstraints(
              minHeight: knopBreedte * 0.5,
              minWidth: knopBreedte,
              maxWidth: knopBreedte,
            ),
            child: DecoratedBox(
              decoration: BoxDecoration(
                color: kleurAnimatie.value,
                borderRadius: BorderRadius.circular(12),
                boxShadow: [
                  BoxShadow(
                    color: Colors.black,
                    blurRadius: 1.0,
                  )
                ],
                border: Border.all(
                  color: randAnimatie
                      .value!, //geen nul safety:verwijder uitroepteken.
                  width: 2,
                ),
              ),
              child: Center(
                child: Text(
                  widget.antwoord,
                  textAlign: TextAlign.center,
                  style: lib.basisTekst,
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
